'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var _reactRouterRedux = require('react-router-redux');

var _reactRouter = require('react-router');

require('./polyfill');

var _store = require('./store');

var _store2 = _interopRequireDefault(_store);

var _container = require('./container');

var _container2 = _interopRequireDefault(_container);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @param { object } routes 请参考react-router@3.x.x的配置模式，必填
 * @param { array } reduers 传递给redux combineReducers，详细请参考redux@3.x.x，必填
 * @param { array } defaultLocale 默认的语言列表，可空
 * @param { object } domContainer dom节点对象，默认值是document.getElementById('root')
 */
function app(routes, reducers, defaultLocale, domContainer) {
  if (defaultLocale) {
    //多语言切换reducer
    var localeReducer = function localeReducer(state, action) {
      if (!state) {
        state = {
          defaultLocale: defaultLocale
        };
      }
      switch (action.type) {
        case '@@locale/CHANGE':
          return Object.assign({}, state, {
            changedLocale: action.locale
          });
          break;
        default:
          return state;
      }
    };
    //reducers整合


    reducers = Object.assign({}, {
      locale: localeReducer
    }, reducers);
  }
  var store = (0, _store2.default)({}, _reactRouter.browserHistory, reducers);
  var history = (0, _reactRouterRedux.syncHistoryWithStore)(_reactRouter.browserHistory, store, {
    selectLocationState: function selectLocationState(state) {
      if (process.env.useImmutable) {
        return state.get('routing').toJS();
      } else {
        return state.routing;
      }
    }
  });
  function renderApp() {
    var target = domContainer || document.getElementById('root');
    if (target) {
      (0, _reactDom.render)(_react2.default.createElement(_container2.default, { store: store, history: history, routes: routes }), target);
    }
  }

  return renderApp;
}

exports.default = app;